SSHSIG
======

Python port of the lightweight SSH Signature format in `ssh-keygen`.

SSHSIG armored, blob, and signed data formats are documented in a file named
`PROTOCOL.sshsig` which is archived from <https://github.com/openssh/openssh-portable> at
<https://archive.softwareheritage.org/swh:1:cnt:78457ddfc653519c056e36c79525712dafba4e6e>.
